SeaIceModes <- function(var, exp, obs, sdates, seasoninf, seasonsup, nclusters = 4, nleadtime = NULL, nmember = NULL, leadtimemin = 1, leadtimemax = NULL, storefreq = "monthly", sampleperiod = 1) {
  #
  # This function computes sea ice modes of variability based on the k-mean
  # method applied to sea ice area or extent averages over the Arctic Seas.
  #
  # Args:
  #   var can be sia or sie (sea ice area or extent)
  #   exp, obs, sdates, nleadtime, nmember, leadtimemin, leadtimemax, 
  #            storefreq are sampleperiod are the same as in Load;
  #            only exp, obs and sdates are compulsory
  #   seasoninf is the month of the year month when to start computing the 
  #            extended seasonal means: 1 to 12.
  #   seasonsup is the month of the year when to stop computing the extended
  #            seasonal means: 1 to 12. The extended seasonal means can overlap
  #            the 31s December: DJF average for example.
  #   nclusters : number of clusters to be computed
  #
  # Return:
  #   clusters : 3-dimensional matrice (x, y, nclusters) containing the
  #              centroides  
  #   pvalue   : 3-dimensional matrice (x, y, nclusters) containing the
  #              pvalue of the centroide anomalies obtained through a t-test
  #              that accounts for the serial dependence of the data
  #   occurrences : 2-dimension matrice (nclusters, time) containing 1 (when
  #                 a given cluster occurs) or 0 (when it does not occur)
  #
  # History:
  #
###############################################################################

# For the loading stage, you should define listseas :

listseas=c( 'Arctic_Marginal_Seas', 'Arctic_Ocean', 'Baffin', 'Baffin_Bay', 'Baltic_Sea', 'BarKara', 'Barents_Sea', 'Beaufort_Sea', 'Bering_Strait', 'Canadian_Waters', 'Central_Arctic', 'Chukchi_Sea', 'East_Siberian_Sea', 'Fram_Strait', 'Greenland_Sea', 'Grnland', 'Icelandic_Sea', 'Kara_Gate_Strait', 'Kara_Sea', 'Laptev_Sea', 'Labrador_Sea', 'Lincoln_Sea', 'Nares_Strait', 'Nordic_Seas', 'NorthWest_Passage', 'North_Atlantic_Ocean', 'Norwegian_Sea', 'OpenOcean', 'Serreze_Arctic', 'TotalArc', 'Vilkitsky_Strait', 'Western_Central_Arctic' )

# then you can loop : 

for (sea in listseas) {
   tmp=Load(paste(var,sea,sep='_'),exp,obs,sdates,nleadtime=nleadtime,nmember=nmember,leadtimemin=leadtimemin,leadtimemax=leadtimemax,storefreq=storefreq,sampleperiod=sampleperiod)  
## print(dim(tmp$mod))
   tmpe1=Season(tmp$mod,posdim=4,monini=as.integer(substr(sdates,5,6)),moninf=seasoninf,monsup=seasonsup)
#  tmpo1=Season(tmp$obs,posdim=4,monini=substr(sdates,5,6),moninf=seasoninf,monsup=seasonsup)
## print(dim(tmpe1))
   tmpe2=Mean1Dim(tmpe1,2)
#  tmpo2=Mean1Dim(tmpo1,2)
## print(dim(tmpe2))

# and all the other arguments passed to SeaIceeModes
# call Season over tmp and passing seasoninf and seasonsup

     if (listseas[1] == sea) { 
       sagae=array(dim=c(length(tmpe2[1,1,]),length(listseas)))
#      sagao=array(dim=c(length(tmpo2[1,1,]),length(listseas)))
       ii=1
       sagae[,ii]=tmpe2[1,1,]
##     print(dim(sagae))
#      sagao[,ii]=tmpo2[1,1,]
       }
       else { 
             ii=ii+1
             sagae[,ii]=tmpe2[1,1,]
#            sagao[,ii]=tmpo2[1,1,]
            }
# then fill saga with the ensemble mean of tmp2
# end of the loop over the seas to fill saga 
}

# Once you have recoded the lines above and you have made a few tests on the 
# computation of clusters, you can work on adding the step of computing
# the weights to be sent to Cluster at this location of the function. For now,
# I have set weights to 1 as a default so that they don't bother you for the
# first tests.

# Then here, you send saga to the Cluster function
# You obtain the array of occurrences that you can use to composite the sea ice
# concentration to obtain clusters with dimensions (x, y, time). To do so,
# you need to call Load('sic', wil all the arguments used when loading the area
# averages)
#
# Then you call the function Composite to obtain the clusters on the (x,y,time)
# grid and their pvalue
#
 
 bubi1=Cluster(sagae) 
 print(' ')
 print('and time series of occurance')
 print(' ')
 print(bubi1$cluster)

invisible(bubi1)

}
